@@ -1,4 +1,4 @@
-INSERT INTO version (table_name, table_version) values ('dialog','3');
+INSERT INTO version (table_name, table_version) values ('dialog','5');
 CREATE TABLE dialog (
     id SERIAL PRIMARY KEY NOT NULL,
     hash_entry INTEGER NOT NULL,
@@ -18,10 +18,23 @@ CREATE TABLE dialog (
     callee_sock VARCHAR(64) NOT NULL,
     state INTEGER NOT NULL,
     start_time INTEGER NOT NULL,
-    timeout INTEGER NOT NULL,
-    sflags INTEGER NOT NULL,
-    toroute INTEGER NOT NULL
+    timeout INTEGER DEFAULT 0 NOT NULL,
+    sflags INTEGER DEFAULT 0 NOT NULL,
+    toroute INTEGER DEFAULT 0 NOT NULL,
+    toroute_name VARCHAR(32),
+    req_uri VARCHAR(128) NOT NULL
 );
 
 CREATE INDEX dialog_hash_idx ON dialog (hash_entry, hash_id);
 
+INSERT INTO version (table_name, table_version) values ('dialog_vars','1');
+CREATE TABLE dialog_vars (
+    id SERIAL PRIMARY KEY NOT NULL,
+    hash_entry INTEGER NOT NULL,
+    hash_id INTEGER NOT NULL,
+    dialog_key VARCHAR(128) NOT NULL,
+    dialog_value VARCHAR(512) NOT NULL
+);
+
+CREATE INDEX dialog_vars_hash_idx ON dialog_vars (hash_entry, hash_id);
+
